/*
 * SonarQube
 * Copyright (C) 2009-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package org.sonar.server.organization;

public class BillingValidationsProxyImpl implements BillingValidationsProxy {

  private final BillingValidationsExtension billingValidationsExtension;

  public BillingValidationsProxyImpl(BillingValidationsExtension billingValidationsExtension) {
    this.billingValidationsExtension = billingValidationsExtension;
  }

  // Used when no plugin is providing the extension
  public BillingValidationsProxyImpl() {
    this.billingValidationsExtension = null;
  }

  @Override
  public void checkOnProjectAnalysis(Organization organization) {
    if (billingValidationsExtension == null) {
      return;
    }
    billingValidationsExtension.checkOnProjectAnalysis(organization);
  }

  @Override
  public void checkCanUpdateProjectVisibility(Organization organization, boolean updateToPrivate) {
    if (billingValidationsExtension == null) {
      return;
    }
    billingValidationsExtension.checkCanUpdateProjectVisibility(organization, updateToPrivate);
  }

  @Override
  public boolean canUpdateProjectVisibilityToPrivate(Organization organization) {
    return billingValidationsExtension == null || billingValidationsExtension.canUpdateProjectVisibilityToPrivate(organization);
  }
}
